@@ -54,6 +54,7 @@ our %EXPORT_TAGS = (
 		   SCMP_FLTATR_ACT_DEFAULT
 		   SCMP_FLTATR_CTL_NNP
 		   SCMP_FLTATR_CTL_TSYNC
+		   SCMP_FLTATR_API_TSKIP
 		   SCMP_VER_MAJOR
 		   SCMP_VER_MICRO
 		   SCMP_VER_MINOR
@@ -458,7 +459,13 @@ our %EXPORT_TAGS = (
 		   __PNR_vm86
 		   __PNR_vm86old
 		   __PNR_vserver
-		   __PNR_waitpid/]
+		   __PNR_waitpid
+
+		  __PNR_pkey_mprotect __NR_pkey_mprotect __PNR_pkey_alloc
+		  __NR_pkey_alloc __PNR_pkey_free __NR_pkey_free
+
+		  __PNR_get_tls __NR_get_tls __PNR_s390_guarded_storage
+		  __NR_s390_guarded_storage __PNR_s390_sthyi __NR_s390_sthyi/]
 );
 
 $EXPORT_TAGS{all} = [@{$EXPORT_TAGS{functions}}, @{$EXPORT_TAGS{macros}}];
@@ -467,7 +474,7 @@ our @EXPORT = @{$EXPORT_TAGS{macros}};
 
 our $VERSION;
 BEGIN{
-	$VERSION = '0.002001';
+	$VERSION = '0.003';
 }
 
 sub AUTOLOAD {
@@ -753,6 +760,13 @@ will fail).
 Specifies whether the kernel should synchronize the filters accross
 all threads when B<load> is called. Defaults to 0 (off).
 
+=item SCMP_FLTATR_API_TSKIP
+
+Specifies whether rules for the system call -1 should be allowed. This
+value can be used by tracer programs to skip specific system call
+invocations, see L<seccomp(2)> for more information. Defaults to 0
+(off).
+
 =back
 
 See L<seccomp_attr_get(3)>.
@@ -861,6 +875,7 @@ Here is a list of all of them:
   SCMP_FLTATR_ACT_DEFAULT
   SCMP_FLTATR_CTL_NNP
   SCMP_FLTATR_CTL_TSYNC
+  SCMP_FLTATR_API_TSKIP
   SCMP_VER_MAJOR
   SCMP_VER_MICRO
   SCMP_VER_MINOR
